@@ -1,10 +1,12 @@
-pub mod config_update_admin_authority;
-pub mod config_update_frame_interval;
+pub mod admin_create_daemon;
+pub mod admin_create_revenue;
+pub mod admin_schedule_health_check;
+pub mod config_update_admin;
 pub mod config_update_program_fee;
 pub mod config_update_worker_fee;
 pub mod daemon_create;
 pub mod daemon_invoke;
-pub mod frame_create;
+pub mod health_check;
 pub mod initialize;
 pub mod revenue_collect;
 pub mod revenue_create;
@@ -13,13 +15,15 @@ pub mod task_create;
 pub mod task_execute;
 pub mod task_repeat;
 
-pub use config_update_admin_authority::*;
-pub use config_update_frame_interval::*;
+pub use admin_create_daemon::*;
+pub use admin_create_revenue::*;
+pub use admin_schedule_health_check::*;
+pub use config_update_admin::*;
 pub use config_update_program_fee::*;
 pub use config_update_worker_fee::*;
 pub use daemon_create::*;
 pub use daemon_invoke::*;
-pub use frame_create::*;
+pub use health_check::*;
 pub use initialize::*;
 pub use revenue_collect::*;
 pub use revenue_create::*;
