@@ -4,24 +4,32 @@ pub mod state;
 
 use {anchor_lang::prelude::*, instructions::*, state::*};
 
-declare_id!("9cEqpQLV3VGN6mBtFKwheJoreg6BXvyCf6pWWDA1FhRf");
+declare_id!("EikDpw2iRwqMrDwGBxAdbdfVAURkvDajZLWrFoYc2dc5");
 
 #[program]
 pub mod cronos {
     use super::*;
 
-    pub fn config_update_admin_authority(
-        ctx: Context<ConfigUpdateAdminAuthority>,
-        new_admin_authority: Pubkey,
-    ) -> ProgramResult {
-        config_update_admin_authority::handler(ctx, new_admin_authority)
+    pub fn admin_create_daemon(ctx: Context<AdminCreateDaemon>, bump: u8) -> ProgramResult {
+        admin_create_daemon::handler(ctx, bump)
     }
 
-    pub fn config_update_frame_interval(
-        ctx: Context<ConfigUpdateFrameInterval>,
-        new_frame_interval: u64,
+    pub fn admin_create_revenue(ctx: Context<AdminCreateRevenue>, bump: u8) -> ProgramResult {
+        admin_create_revenue::handler(ctx, bump)
+    }
+
+    pub fn admin_schedule_health_check(
+        ctx: Context<AdminScheduleHealthCheck>,
+        bump: u8,
     ) -> ProgramResult {
-        config_update_frame_interval::handler(ctx, new_frame_interval)
+        admin_schedule_health_check::handler(ctx, bump)
+    }
+
+    pub fn config_update_admin(
+        ctx: Context<ConfigUpdateAdmin>,
+        new_admin: Pubkey,
+    ) -> ProgramResult {
+        config_update_admin::handler(ctx, new_admin)
     }
 
     pub fn config_update_program_fee(
@@ -49,22 +57,18 @@ pub mod cronos {
         daemon_invoke::handler(ctx, instruction_data)
     }
 
-    pub fn frame_create(
-        ctx: Context<WindowCreate>,
-        timestamp: u64,
-        frame_bump: u8,
-        list_bump: u8,
-    ) -> ProgramResult {
-        frame_create::handler(ctx, timestamp, frame_bump, list_bump)
-    }
-
     pub fn initialize(
         ctx: Context<Initialize>,
         authority_bump: u8,
         config_bump: u8,
+        health_bump: u8,
         treasury_bump: u8,
     ) -> ProgramResult {
-        initialize::handler(ctx, authority_bump, config_bump, treasury_bump)
+        initialize::handler(ctx, authority_bump, config_bump, health_bump, treasury_bump)
+    }
+
+    pub fn health_check(ctx: Context<HealthCheck>) -> ProgramResult {
+        health_check::handler(ctx)
     }
 
     pub fn revenue_collect(ctx: Context<RevenueCollect>) -> ProgramResult {
@@ -85,8 +89,7 @@ pub mod cronos {
         execute_at: u64,
         repeat_every: u64,
         repeat_until: u64,
-        task_bump: u8,
-        task_element_bump: u8,
+        bump: u8,
     ) -> ProgramResult {
         task_create::handler(
             ctx,
@@ -94,8 +97,7 @@ pub mod cronos {
             execute_at,
             repeat_every,
             repeat_until,
-            task_bump,
-            task_element_bump,
+            bump,
         )
     }
 
@@ -103,11 +105,7 @@ pub mod cronos {
         task_execute::handler(ctx)
     }
 
-    pub fn task_repeat(
-        ctx: Context<TaskRepeat>,
-        next_task_bump: u8,
-        next_task_element_bump: u8,
-    ) -> ProgramResult {
-        task_repeat::handler(ctx, next_task_bump, next_task_element_bump)
+    pub fn task_repeat(ctx: Context<TaskRepeat>, bump: u8) -> ProgramResult {
+        task_repeat::handler(ctx, bump)
     }
 }
