@@ -1,7 +1,7 @@
 pub mod authority;
 pub mod config;
 pub mod daemon;
-pub mod frame;
+pub mod health;
 pub mod revenue;
 pub mod task;
 pub mod treasury;
@@ -9,7 +9,7 @@ pub mod treasury;
 pub use authority::*;
 pub use config::*;
 pub use daemon::*;
-pub use frame::*;
+pub use health::*;
 pub use revenue::*;
 pub use task::*;
 pub use treasury::*;
